from selenium import webdriver
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.by import By
from selenium.webdriver.chrome.options import Options
from selenium.common.exceptions import NoSuchElementException
from webdriver_manager.chrome import ChromeDriverManager
from selenium.webdriver.common.keys import Keys
import os
import sys

def blast(name):
	script_path = sys.path[0]

	# enter the number of the person by the user
	target = str(name) #str(input("Enter the name of target: "))
	message = str(input("Enter your message: "))
	n = int(input("Enter the number of messages to blast: "))

	# chrome driver
	chrome_options = Options()
	driver = webdriver.Chrome(ChromeDriverManager().install())
	driver.get("https://web.whatsapp.com/")
	wait = WebDriverWait(driver, 600)
	assert "WhatsApp" in driver.title

	# finds the target and navigate to it
	x_arg = '//span[contains(@title, '+ '"' +target + '"'+ ')]'
	person_title = wait.until(EC.presence_of_element_located((By.XPATH, x_arg)))
	print(target)
	person_title.click()

	# navigate to text part
	xpath = '//div[@class="_3u328 copyable-text selectable-text"]'
	message_area = wait.until(EC.presence_of_element_located((By.XPATH, xpath)))

	# sends message multiple times
	for i in range(n):
		message_area.send_keys(message + Keys.ENTER)



from selenium import webdriver
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.by import By
from selenium.webdriver.chrome.options import Options
from selenium.common.exceptions import NoSuchElementException
from webdriver_manager.chrome import ChromeDriverManager
from selenium.webdriver.common.keys import Keys
import os
import sys

def chat(name):
	script_path = sys.path[0]

	# chrome driver
	chrome_options = Options()
	driver = webdriver.Chrome(ChromeDriverManager().install())
	driver.get("https://web.whatsapp.com/")
	wait = WebDriverWait(driver, 600)
	assert "WhatsApp" in driver.title

	condition=True
	while condition:
		print("1. Chat")
		print("2. Quit")
		option = int(input("Enter choice: "))
		
		if option==1:
			# enter the name of the person by the user
			receiver =  str(name) #str(input("Enter the name of receiver: "))
			message = str(input("Enter your message: "))

			# finds the person and navigate to it
			x_arg = '//span[contains(@title, '+ '"' +receiver + '"'+ ')]'
			person_title = wait.until(EC.presence_of_element_located((By.XPATH, x_arg)))
			print(receiver)
			person_title.click()

			# navigate to text part
			xpath = '//div[@class="_3u328 copyable-text selectable-text"]'
			message_area = wait.until(EC.presence_of_element_located((By.XPATH, xpath)))

			# sends message
			message_area.send_keys(message + Keys.ENTER)

		if option==2:
			condition=False
			exit()



import argparse
from wplay import onlinetracker
from wplay import messageblast
from wplay import wchat
import sys

# parse positional and optional arguments
def get_arguments():
	parser = argparse.ArgumentParser(description='WhatApp-play')
	parser.add_argument("name", metavar="NAME", type=str, help="contact name of the target")

	group = parser.add_mutually_exclusive_group(required=True)
	group.add_argument("-wc", "--wchat", action="store_true", help="chatting from command line")
	group.add_argument("-wb", "--wblast", action="store_true", help="message blast to a person")
	group.add_argument("-wt", "--wtrack", action="store_true", help="track online status of person")

	args = parser.parse_args()
	return args

def match_args(args):
	if args.wtrack:
		onlinetracker.tracker(args.name)

	elif args.wchat:
		wchat.chat(args.name)

	elif args.wblast:
		messageblast.blast(args.name)

def main():
	args = get_arguments()
	try:
		match_args(args)
		sys.exit(0)
	except KeyboardInterrupt as e:
		sys.exit(0)


if __name__=='__main__':
	main()



from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
	name="wplay",
	version="1.0.6",
	install_requires=["selenium >= 3.141.0",
                    "python-telegram-bot >= 11.1.0",
                    "datetime >= 4.3",
                    "webdriver-manager >= 1.7"],
	packages=find_packages(),
	description="command line software to play with your WhatsApp",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Rohit Potter",
    author_email="rohitpotter12@gmail.com",
    license="MIT",
    python_requires=">=3.4",
    url="https://github.com/rpotter12/whatsapp-play/",
    download_url="https://pypi.org/project/wplay/",
    keywords=[
        "whatsapp",
        "whatsapp-cli",
        "whatsapp-chat",
        "message-blast",
        "tracker"
    ],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={"console_scripts": ["wplay = wplay.wplay:main"]},
	)


from selenium import webdriver
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.by import By
from selenium.webdriver.chrome.options import Options
from selenium.common.exceptions import NoSuchElementException, StaleElementReferenceException
from webdriver_manager.chrome import ChromeDriverManager
import time
import datetime
import os
import sys

def tracker(name):
	script_path = sys.path[0]

	# enter the name of the person by the user
	target = str(name) #str(input("Enter the name of target: "))

	# chrome driver
	chrome_options = Options()
	driver = webdriver.Chrome(ChromeDriverManager().install())
	driver.get("https://web.whatsapp.com/")
	wait = WebDriverWait(driver, 600)
	assert "WhatsApp" in driver.title

	# finds the target and navigate to it
	x_arg = '//span[contains(@title, '+ '"' +target + '"'+ ')]'
	person_title = wait.until(EC.presence_of_element_located((By.XPATH, x_arg)))
	print(target)
	person_title.click()

	f=open('status.txt','w')
	f.close()
	# check status
	while True:
		i=0
		try:
			status = driver.find_element_by_class_name('_315-i').text
			i=1
		except (NoSuchElementException, StaleElementReferenceException):
			status = 'offline'
			i=0
		print(datetime.datetime.now())
		print(status)
		f=open('status.txt','a')
		f.write(str(datetime.datetime.now()))
		f.write(status)
		f.close()
		while True:
			if i == 1:
				try:
					re_status = driver.find_element_by_class_name('_315-i').text
					continue
				except (NoSuchElementException, StaleElementReferenceException):
					re_status = 'offline'
					break
			else:
				try:
					re_status = driver.find_element_by_class_name('_315-i').text
					break
				except (NoSuchElementException, StaleElementReferenceException):
					re_status = 'offline'
					continue
		time.sleep(1)
